"""
辅助函数
"""

from pathlib import Path
import matplotlib.pyplot as plt
import scipy.io as sio


def save_matrix(matrix, file_name):
    # TODO: 存储 matrix 到 file_name.mat, mdict 的 key 为 "matrix"
    sio.savemat(file_name + '.mat', {'matrix': matrix})
    # raise NotImplementedError


def save_fig(matrix, file_name):
    # TODO: 将 matrix 画图保存到 file_name.jpg
    plt.imshow(matrix)
    plt.savefig(file_name + '.jpg')
    # raise NotImplementedError


def make_dir(outdir):
    # TODO: 当目录 outdir 不存在时创建目录
    Path(outdir).mkdir(parents=True, exist_ok=True)
    # raise NotImplementedError



# TODO 正确导入函数 generate_matrix, save_matrix, save_fig
from simplelayout.generator.utils import save_matrix, save_fig, make_dir
from simplelayout.generator.core import generate_matrix
from simplelayout.cli import get_options  # TODO: 保证不修改本行也可以正确导入


def main():
    options = get_options()
    matrix = generate_matrix(options.board_grid, options.unit_grid,
                             options.unit_n, options.positions)
    make_dir(options.outdir)
    save_matrix(matrix, options.outdir + '/' + options.file_name)
    save_fig(matrix, options.outdir + '/' + options.file_name)
    # raise NotImplementedError
    #  TODO 使用导入的函数按命令行参数生成数据，包括 mat 文件与 jpg 文件


if __name__ == "__main__":
    main()



# TODO: 导入generator_matrix,save_fig, save_matrix, make_dir

from simplelayout.generator.core import generate_matrix
from simplelayout.generator.utils import save_fig
from simplelayout.generator.utils import save_matrix
from simplelayout.generator.utils import make_dir



"""
数据生成的主要逻辑
"""

import numpy as np
import matplotlib.pyplot as plt


def generate_matrix(
    board_grid: int, unit_grid: int, unit_n: int, positions: list
) -> np.ndarray:
    matrix = np.zeros((board_grid, board_grid))
    for item in positions:
        board_unit_n = board_grid/unit_grid
        if item % board_unit_n == 0:
            row_n = int(item/board_unit_n - 1)
            column_n = board_unit_n - 1
        else:
            row_n = int(item/board_unit_n)
            column_n = int(item % board_unit_n - 1)
        print(row_n, column_n)
        row_begin = int(row_n*unit_grid)
        column_begin = int(column_n*unit_grid)
        print(row_begin, row_begin + unit_grid,
              column_begin, column_begin + unit_grid)
        matrix[row_begin:row_begin + unit_grid,
               column_begin:column_begin + unit_grid] = 1
    plt.imshow(matrix)
    plt.savefig('matrix')
    return matrix

    """生成指定布局矩阵

    Args:
        board_grid (int): 布局板分辨率，代表矩形区域的边长像素数
        unit_grid (int): 矩形组件分辨率
        unit_n (int): 组件数
        positions (list): 每个元素代表每个组件的位置
    Returns:
        np.ndarray: 布局矩阵
    """
    # raise NotImplementedError  # TODO: 实现布局矩阵的生成



import argparse
import sys


def get_options():
    parser = argparse.ArgumentParser()
    # TODO: 按 1-simplelayout-CLI 要求添加相应参数
    parser.add_argument("--board_grid", type=int,
                        help="the board_grid")
    parser.add_argument("--unit_grid", type=int,
                        help="the unit_grid")
    parser.add_argument("--unit_n", type=int,
                        help="the number_of_unit")
    parser.add_argument("--positions", type=int, nargs='+',
                        help="the positions")
    parser.add_argument("-o", "--outdir", type=str, default='/example_dir',
                        help="the outdir")
    parser.add_argument("--file_name", type=str, default='example',
                        help="the file_name")
    options = parser.parse_args()
    n = options.board_grid/options.unit_grid
    if options.board_grid % options.unit_grid != 0:
        sys.exit('不能整除')
    elif len(options.positions) != options.unit_n:
        sys.exit('组件数量错误')
    elif min(options.positions) < 1 | max(options.positions) > n**2:
        sys.exit('组件编号超出范围')
    else:
        return options



import setuptools
import pathlib

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="simplelayout-Vincentius1990",
    version="0.0.2",
    author="Vincentius1990",
    author_email="vincent1990@126.com",
    description="A small example package",
    # long_description=long_description,
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    entry_points={
        'console_scripts': [
            "simplelayout = simplelayout.__main__:main",
        ],
    },
    install_requires=['matplotlib', 'numpy', 'scipy']
)
